@@ -9,12 +9,15 @@ KEYWORDS_DOWN = ('args', 'kwargs')
 UUID_REGEX = re.compile(r'^[\w]{8}(-[\w]{4}){3}-[\w]{12}$')
 
 
+def format_time(time):
+    return datetime.fromtimestamp(time).strftime("%Y-%m-%d %H:%M:%S")
+
+
 def humanize(obj, type=None, length=None):
     if obj is None:
         obj = ''
     elif type == 'time':
-        obj = datetime.fromtimestamp(
-            float(obj)).strftime("%Y-%m-%d %H:%M:%S") if obj else '-'
+        obj = format_time(float(obj)) if obj else '-'
     elif isinstance(obj, basestring) and not re.match(UUID_REGEX, obj):
         obj = obj.replace('-', ' ').replace('_', ' ')
         obj = re.sub('|'.join(KEYWORDS_UP),
